% % Burst Size
% % Burst Frequency
% % 
% % We have to supply the fraction by which mean expression variation 
% % is determined by burst size or burst frequency variation and see how the
% % difference in up- and down-regulation is affected by this fraction.


% % TRANSCRIPTION SIMULATION 
totNum = 12000;
ncell = 200;

lam0 = 0.2;     % s^-1
kon0 = 0.0013;  % s^-1
koff0 = 0.01;   % s^-1
tau0 = 1800;    % s

% % Average read count is ~10^2, maximum ~10^3.5, i.e. var ~ 2 in log10
% % space. In log2 space, this corresponds to a variance of 7.3.
% % This then gets split between frequency and size.
% % 75% variance is stdev of 2.34
% % 50% variance is stdev of 1.91
% % 25% variance is stdev of 1.35
% % ...

% % e.g. situation A - size 50, freq 50
sd50 = 1.91;
sdlam = sd50;
sdkon = sd50;

lamvals = lam0 * 2.^(sdlam * randn(totNum,1));
konvals = kon0 * 2.^(sdkon * randn(totNum,1));

% % generatescseqdata(kon, koff, lambda, tau, ncells, tpoint, dwell, saveinterval)
rnacountsS = generatescseqdata(konvals, koff0, lamvals, tau0, ncell, 4500, 120);

% % Export
save situationA
csvwrite('sim.csv', rnacountsS)


% % CALCULATING meanExp, CV2, DM
% % S is a structure: meancounts, cv2, DM
S = scrnaseqprocess(rnacountsS(1:totNum,:));

% % Plot CV2/meanExp
sdk = 50; sdl = 50; % labels
dfig
loglog(S.meancounts,S.cv2,'.','color',[0.7,0.7,0.7],'LineWidth',2,'MarkerSize',8)
hold on
title([sprintf('freq: ') num2str(sdk) '%  size: ' num2str(sdl) '%'])
axis([0.01,10^5,0.0005,ncell+10])
xlabel('Mean Expression')
ylabel('CV^2')
hold off

% % Export
print('sim_CVplot', '-dpng', '-r300');
% csvwrite('sim_DM.csv',S.DM)


% % GIBBS SAMPLING - PAIRING
high = 5; low = 0.3; % 'low' limits the variance
paramsigma = [high, high]; % e.g.
% uncomment the line below for frequency regulated:
% paramsigma = [high, low]
% uncomment the line below for burst size regulated:
% paramsigma = [low, high]

% indices
pairindsS = gibbsgenepairs(log2([konvals,lamvals]),paramsigma, S.meancounts, 2000, 1000, [2,Inf]);

% Group stats
downS = regustats(S,pairindsS(:,1),10);
upS = regustats(S,pairindsS(:,2),10); 

% Plot
dfig
plot(S.meancounts,S.DM,'.','color',[0.7,0.7,0.7])
togglelog x
hold on
errorbar(downS.mean(:,1),downS.mean(:,2),downS.stderr(:,2),'.','color',[0.2,0,0.4],'LineWidth',1.5,'MarkerSize',12)
errorbar(upS.mean(:,1),upS.mean(:,2),upS.stderr(:,2),'.','color',[0,0,0],'LineWidth',1.5,'MarkerSize',12)
ax = gca;
set(ax,'xlim',[1,1e4])
set(ax,'YLim',[-1,1])
addlabels('Mean Expression','DM')
title(sprintf('regulation\nSDfreq = SDsize'))

% % Export
print('sim_regulation', '-dpng', '-r300');
csvwrite('sim_pairs.csv',pairindsS)
